@@ -457,7 +457,14 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
 
                     # Check if we are past the 'known' responses
                     if i >= len_command_defn:
-                        response_defn = [i, "str", f"Unknown value in response {i}", ""]
+                        if not response:
+                            continue
+                        response_defn = [
+                            i + 1,
+                            f"Unknown value in response {i+1}",
+                            "str",
+                            "",
+                        ]
                     else:
                         response_defn = command_defn["response"][i]
                     log.debug(f"Got defn {response_defn}")
@@ -549,7 +556,10 @@ class AbstractProtocol(metaclass=abc.ABCMeta):
                     for item in processed_responses:
                         data_name, value, data_units, extra_info = item
                         if data_name is not None:
-                            msgs[data_name] = [value, data_units, extra_info]
+                            if extra_info:
+                                msgs[data_name] = [value, data_units, extra_info]
+                            else:
+                                msgs[data_name] = [value, data_units]
             # print(f"{i=} {response=} {len(command_defn['response'])}")
 
         return msgs
